@@ -95,7 +95,7 @@ void Quickview::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(775, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myQuickviewConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myQuickviewConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 
@@ -109,7 +109,7 @@ void Quickview::readConfig()
 
 void Quickview::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myQuickviewConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myQuickviewConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     const QList<int> list = mAgendaView->splitter()->sizes();
     group.writeEntry("Separator", list);
